==> haskell-case-insensitive-1.2.0.8-2-x86_64.pkg.tar.xz: usr/share/haskell/register/haskell-case-insensitive.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
echo 'name: case-insensitive
version: 1.2.0.8
id: case-insensitive-1.2.0.8-19yABacCVqnEmCaYKTVngi
key: case-insensitive-1.2.0.8-19yABacCVqnEmCaYKTVngi
license: BSD3
copyright: 2011 Bas van Dijk
maintainer: Bas van Dijk <v.dijk.bas@gmail.com>
homepage: https://github.com/basvandijk/case-insensitive
synopsis: Case insensitive string comparison
description:
    The module @Data.CaseInsensitive@ provides the '\''CI'\'' type
    constructor which can be parameterised by a string-like
    type like: '\''String'\'', '\''ByteString'\'', '\''Text'\'',
    etc.. Comparisons of values of the resulting type will be
    insensitive to cases.
category: Data, Text
author: Bas van Dijk
exposed: True
exposed-modules:
    Data.CaseInsensitive Data.CaseInsensitive.Unsafe
hidden-modules: Data.CaseInsensitive.Internal
abi: bcc482f9d776eacdc10fddcdae6ebf01
trusted: False
import-dirs: /usr/lib/ghc-8.0.1/site-local/case-insensitive-1.2.0.8
library-dirs: /usr/lib/ghc-8.0.1/site-local/case-insensitive-1.2.0.8
data-dir: /usr/share/x86_64-linux-ghc-8.0.1/case-insensitive-1.2.0.8
hs-libraries: HScase-insensitive-1.2.0.8-19yABacCVqnEmCaYKTVngi
depends:
    base-4.9.0.0 bytestring-0.10.8.1 deepseq-1.4.2.0
    hashable-1.2.6.0-En2FSYN34Tp8YO8pqagtg1
    text-1.2.2.1-FgcR4Xf0VlEHD9HLxzq9WJ
haddock-interfaces: /usr/share/doc/haskell-case-insensitive/html/case-insensitive.haddock
haddock-html: /usr/share/doc/haskell-case-insensitive/html
' | '/usr/bin/ghc-pkg' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"

==> haskell-case-insensitive-1.2.0.9-1-x86_64.pkg.tar.xz: usr/share/haskell/register/haskell-case-insensitive.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
echo 'name: case-insensitive
version: 1.2.0.9
id: case-insensitive-1.2.0.9-HR7ngNnTOX66jDpe7AgOeu
key: case-insensitive-1.2.0.9-HR7ngNnTOX66jDpe7AgOeu
license: BSD3
copyright: 2011 Bas van Dijk
maintainer: Bas van Dijk <v.dijk.bas@gmail.com>
homepage: https://github.com/basvandijk/case-insensitive
synopsis: Case insensitive string comparison
description:
    The module @Data.CaseInsensitive@ provides the '\''CI'\'' type
    constructor which can be parameterised by a string-like
    type like: '\''String'\'', '\''ByteString'\'', '\''Text'\'',
    etc.. Comparisons of values of the resulting type will be
    insensitive to cases.
category: Data, Text
author: Bas van Dijk
exposed: True
exposed-modules:
    Data.CaseInsensitive Data.CaseInsensitive.Unsafe
hidden-modules: Data.CaseInsensitive.Internal
abi: 24b91802f500ce5c4d3ccaaf703223ab
trusted: False
import-dirs: /usr/lib/ghc-8.0.1/site-local/case-insensitive-1.2.0.9
library-dirs: /usr/lib/ghc-8.0.1/site-local/case-insensitive-1.2.0.9
data-dir: /usr/share/x86_64-linux-ghc-8.0.1/case-insensitive-1.2.0.9
hs-libraries: HScase-insensitive-1.2.0.9-HR7ngNnTOX66jDpe7AgOeu
depends:
    base-4.9.0.0 bytestring-0.10.8.1 deepseq-1.4.2.0
    hashable-1.2.6.0-En2FSYN34Tp8YO8pqagtg1
    text-1.2.2.1-FgcR4Xf0VlEHD9HLxzq9WJ
haddock-interfaces: /usr/share/doc/haskell-case-insensitive/html/case-insensitive.haddock
haddock-html: /usr/share/doc/haskell-case-insensitive/html
' | '/usr/bin/ghc-pkg' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"
